Module parser

Module parser 

Functions

detect_help_flag
Detect whether the user-supplied args contain a likely “help” flag.
parse_arguments
Attempt to parse arguments/parameters from usage blocks and Arguments sections.
parse_environment_variables
Parse environment variables from help text.
parse_examples
Parse examples from help text.
parse_options_from_sections
Parse options from separate OPTIONS sections in the help text. This complements parse_options_from_usage_blocks by finding options that appear in dedicated OPTIONS sections.
parse_options_from_usage_blocks
Attempt to parse option/flag lines from the usage blocks and OPTIONS sections.
parse_subcommands
Attempt to parse subcommands from the full help text (stdout+stderr, as strings).
parse_usages
Parse “usage” blocks from stdout/stderr.
parse_validation_rules
Parse validation rules from help text.