Module model
Source - ArgumentSpec
- Structured description of a command argument/parameter.
- CommandTree
- Complete command tree discovered through recursive probing.
- EnvVarSpec
- An environment variable that can be used to configure the command.
- Example
- An example command usage extracted from help text.
- OptionSpec
- Structured description of a single CLI option/flag.
- ProbeResult
- Structured result of probing a command.
- SubcommandSpec
- Structured description of a subcommand (very heuristic).
- ValidationRule
- A validation rule for an option or argument.
- ArgumentType
- Type of an argument, inferred from placeholder or description.
- OptionType
- Type of an option’s value.
- ValidationType
- Types of validation rules.