Functions
- detect_
help_ flag - Detect whether the user-supplied args contain a likely “help” flag.
- parse_
arguments - Attempt to parse arguments/parameters from usage blocks and Arguments sections.
- parse_
environment_ variables - Parse environment variables from help text.
- parse_
examples - Parse examples from help text.
- parse_
options_ from_ sections - Parse options from separate OPTIONS sections in the help text. This complements parse_options_from_usage_blocks by finding options that appear in dedicated OPTIONS sections.
- parse_
options_ from_ usage_ blocks - Attempt to parse option/flag lines from the usage blocks and OPTIONS sections.
- parse_
subcommands - Attempt to parse subcommands from the full help text (stdout+stderr, as strings).
- parse_
usages - Parse “usage” blocks from stdout/stderr.
- parse_
validation_ rules - Parse validation rules from help text.